<?php

declare(strict_types=1);

namespace Drupal\Tests\content_lock\Functional;

use Drupal\Tests\BrowserTestBase;

/**
 * Views tests.
 *
 * @group content_lock
 */
class ContentLockViewsTest extends BrowserTestBase {

  /**
   * {@inheritdoc}
   */
  protected $defaultTheme = 'stark';

  /**
   * {@inheritdoc}
   */
  protected static $modules = [
    'block',
    'node',
    'views',
    'content_lock',
  ];

  /**
   * Test Content Lock view display.
   */
  public function testViewDisplay() {
    $this->drupalPlaceBlock('local_tasks_block');
    $this->drupalCreateContentType(['type' => 'article']);
    $admin = $this->drupalCreateUser([
      'access content overview',
      'administer content lock',
      'administer content types',
      'administer nodes',
      'create article content',
      'delete any article content',
      'edit any article content',
    ]);
    $this->drupalLogin($admin);

    // Visit the content listing view to build the views cache.
    $this->drupalCreateNode(['type' => 'article', 'title' => 'Article 1']);
    $this->drupalGet('/admin/content');
    $this->assertSession()->statusCodeEquals(200);
    $this->assertSession()->elementTextContains('css', '#views-form-content-page-1', 'Article 1');
    $this->assertSession()->linkNotExists('Locked content');

    // Test that the view throws a 403 if no entity is configured.
    $this->drupalGet('/admin/content/locked-content');
    $this->assertSession()->statusCodeEquals(403);

    // Add an entity to be locked.
    $edit = [
      'node[bundles][article]' => 1,
    ];
    $this->drupalGet('admin/config/content/content_lock');
    $this->submitForm($edit, 'Save configuration');

    // Lock some content.
    $this->drupalGet('node/1/edit');

    // Verify view is still accessible and lists the locked node.
    $this->drupalGet('/admin/content');
    $this->clickLink('Locked content');
    $this->assertSession()->addressEquals('admin/content/locked-content');
    $this->assertSession()->statusCodeEquals(200);
    $this->assertSession()->elementTextContains('css', '#views-form-locked-content-page-1', 'Article 1');

    // Test bulk action.
    $this->getSession()->getPage()->checkField('node_bulk_form[0]');
    $this->submitForm(['edit-action' => 'node_break_lock_action'], 'Apply to selected items');
    $this->assertSession()->addressEquals('admin/content/locked-content');
    $this->assertSession()->statusCodeEquals(200);
    $this->assertSession()->elementTextNotContains('css', '#views-form-locked-content-page-1', 'Article 1');
  }

}
